@@ -271,6 +271,9 @@ photos_facebook_item_class_init (PhotosFacebookItemClass *class)
   GObjectClass *object_class = G_OBJECT_CLASS (class);
   PhotosBaseItemClass *base_item_class = PHOTOS_BASE_ITEM_CLASS (class);
 
+  base_item_class->miner_name = "org.gnome.OnlineMiners.Facebook";
+  base_item_class->miner_object_path = "/org/gnome/OnlineMiners/Facebook";
+
   object_class->constructed = photos_facebook_item_constructed;
   object_class->dispose = photos_facebook_item_dispose;
   base_item_class->create_thumbnail = photos_facebook_item_create_thumbnail;
